Structure From Motion {#tutorial_table_of_content_sfm}
=====================

-   @subpage tutorial_sfm_installation

    *Compatibility:* \> OpenCV 3.0

    *Author:* Edgar Riba

    Instructions in order to properly setup the Structure from Motion module.

-   @subpage tutorial_sfm_trajectory_estimation

    *Compatibility:* \> OpenCV 3.0

    *Author:* Edgar Riba

    Camera motion estimation from a given set of tracked 2d points.

-   @subpage tutorial_sfm_scene_reconstruction

    *Compatibility:* \> OpenCV 3.0

    *Author:* Edgar Riba

    Sparse scene reconstruction from a given set of images.

-   @subpage tutorial_sfm_import_reconstruction

    *Compatibility:* \> OpenCV 3.0

    *Author:* Edgar Riba

    Import a scene reconstruction.